@@ -20,14 +20,10 @@ class SimpleClient:
 
     def create_lookup(self, name):
         self.exc.register_lookup(name).commit()
+        return self.exc.register_transformation(name).sink(name, ResourceTypes.Lookup)
 
     def delete_lookup(self, name):
         self.exc.deregister_lookup(name)
-
-    def create_transform(self, name):
-        return self.exc.register_transformation(name)
-
-    def delete_transform(self, name):
         self.exc.deregister_transformation(name)
 
     def lookup(self, table, key=None):
